// bitset.c
// Řešení IJC-DU1, příklad a), 22.3.2024
// Autor: Roman Nečas, FIT
// Přeloženo: gcc 13.2.1
//
#include "bitset.h"

/* Sets the specified bit in the array to the value given by the expression */
extern void bitset_setbit(bitset_t name, bitset_index_t index, bool expr);

extern void bitset_fill(bitset_t name, bool bool_expr);

/* Gets the value of the specified bit, returns 0 or 1 */
extern char bitset_getbit(bitset_t name, bitset_index_t index);

/* Returns the declared size of the array stored at index 0 */
extern unsigned long bitset_size(bitset_t name);
